Trait ObsSourceBuilder
pub trait ObsSourceBuilder: ObsObjectBuilder {
type T: ObsSourceTrait + Clone + 'static;
// Required method
fn build(self) -> Result<Self::T, ObsError>
where Self: Sized;
// Provided method
fn add_to_scene(
self,
scene: &mut ObsSceneRef,
) -> Result<ObsSceneItemRef<Self::T>, ObsError>
where Self: Sized { ... }
}Required Associated Types
Required Methods
Provided Methods
fn add_to_scene(
self,
scene: &mut ObsSceneRef,
) -> Result<ObsSceneItemRef<Self::T>, ObsError>where
Self: Sized,
fn add_to_scene(
self,
scene: &mut ObsSceneRef,
) -> Result<ObsSceneItemRef<Self::T>, ObsError>where
Self: Sized,
Both items are returned: the source and the scene item it was added as. You can safely drop these items, they are stored within the scene if you don’t need them.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl ObsSourceBuilder for PipeWireCameraSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PipeWireCameraSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for PipeWireDesktopCaptureSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PipeWireDesktopCaptureSourceBuilder
Available on Linux only.
type T = ObsPipeWireSourceRef
Sourceimpl ObsSourceBuilder for PipeWireScreenCaptureSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PipeWireScreenCaptureSourceBuilder
Available on Linux only.
type T = ObsPipeWireSourceRef
Sourceimpl ObsSourceBuilder for PipeWireWindowCaptureSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PipeWireWindowCaptureSourceBuilder
Available on Linux only.
type T = ObsPipeWireSourceRef
Sourceimpl ObsSourceBuilder for AlsaInputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for AlsaInputSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for JackOutputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for JackOutputSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for LinuxGeneralScreenCaptureBuilder
Available on Linux only.
impl ObsSourceBuilder for LinuxGeneralScreenCaptureBuilder
Available on Linux only.
type T = ObsEitherSource<ObsSourceRef, ObsPipeWireSourceRef>
Sourceimpl ObsSourceBuilder for LinuxGeneralWindowCaptureBuilder
Available on Linux only.
impl ObsSourceBuilder for LinuxGeneralWindowCaptureBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for PulseInputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PulseInputSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for PulseOutputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for PulseOutputSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for V4L2InputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for V4L2InputSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for X11CaptureSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for X11CaptureSourceBuilder
Available on Linux only.
Sourceimpl ObsSourceBuilder for XCompositeInputSourceBuilder
Available on Linux only.
impl ObsSourceBuilder for XCompositeInputSourceBuilder
Available on Linux only.
type T = XCompositeInputSource
Sourceimpl ObsSourceBuilder for GameCaptureSourceBuilder
Available on Windows only.
impl ObsSourceBuilder for GameCaptureSourceBuilder
Available on Windows only.
type T = GameCaptureSource
Sourceimpl ObsSourceBuilder for MonitorCaptureSourceBuilder
Available on Windows only.
impl ObsSourceBuilder for MonitorCaptureSourceBuilder
Available on Windows only.
type T = MonitorCaptureSource
Sourceimpl ObsSourceBuilder for WindowCaptureSourceBuilder
Available on Windows only.
impl ObsSourceBuilder for WindowCaptureSourceBuilder
Available on Windows only.